#
# spec file for package libgedit-tepl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define api_ver 6
%define lib_ver %{api_ver}-2

Name:           libgedit-tepl
Version:        6.12.0
Release:        1.1
Summary:        Text Editor Product Line
License:        LGPL-3.0-or-later
Group:          Productivity/Text/Editors
URL:            https://wiki.gnome.org/Projects/Tepl
Source:         %{name}-%{version}.tar.zst

BuildRequires:  gobject-introspection-devel >= 1.42.0
BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.53
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.64
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libgedit-amtk-5)
BuildRequires:  pkgconfig(libgedit-gfls-1)
BuildRequires:  pkgconfig(libgedit-gtksourceview-300) >= 299.1.0
BuildRequires:  pkgconfig(libhandy-1) >= 1.6
BuildRequires:  pkgconfig(uchardet)

%description
Tepl is a library that eases the development of GtkSourceView-based text
editors and IDEs. It is a continuation/rename of Gtef.

%package -n libgedit-tepl-%{lib_ver}
Summary:        A text editor framework
Group:          System/Libraries
Provides:       libgedit-tepl-%{api_ver} = %{version}

%description -n libgedit-tepl-%{lib_ver}
Tepl (Text Editor Product Line) is a library that eases the
development of GtkSourceView-based text editors and IDEs. It is a
continuation / rename of Gtef

%package -n typelib-1_0-Tepl-%{api_ver}
Summary:        GObject introspection bindings for libtepl
Group:          System/Libraries

%description -n typelib-1_0-Tepl-%{api_ver}
Tepl is a library that eases the development of GtkSourceView-based text
editors and IDEs. It is a continuation/rename of Gtef.

This package provides the GObject Introspection bindings for tepl.

%package devel
Summary:        Development files for Tepl, a text editor framework
Group:          Development/Libraries/GNOME
Requires:       libgedit-tepl-%{lib_ver} >= %{version}
Requires:       typelib-1_0-Tepl-%{api_ver} >= %{version}

%description devel
Tepl is a library that eases the development of GtkSourceView-based text
editors and IDEs. It is a continuation/rename of Gtef.

This subpackage contains the header files for developing
applications that want to make use of tepl.

%lang_package -n %{name}-%{api_ver}

%prep
%autosetup -p1

%build
%meson \
        -Dgtk_doc=true
%meson_build

%install
%meson_install
%find_lang %{name}-%{api_ver}

%ldconfig_scriptlets -n libgedit-tepl-%{lib_ver}

%files -n libgedit-tepl-%{lib_ver}
%doc LICENSES/LGPL-3.0-or-later.txt
%{_libdir}/libgedit-tepl-%{api_ver}.so.*

%files -n typelib-1_0-Tepl-%{api_ver}
%{_libdir}/girepository-1.0/Tepl-%{api_ver}.typelib

%files devel
%doc %{_datadir}/gtk-doc/html/%{name}-%{api_ver}
%{_datadir}/gir-1.0/Tepl-%{api_ver}.gir
%{_includedir}/libgedit-tepl-%{api_ver}/
%{_libdir}/pkgconfig/libgedit-tepl-%{api_ver}.pc
%{_libdir}/*.so

%files -n %{name}-%{api_ver}-lang -f %{name}-%{api_ver}.lang

%changelog
* Sat Dec  7 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 6.12.0:
  + New and removed API: see the API reference.
  + Fix compilation warnings.
  + Updated translations.
- Bump libver
* Wed Oct  2 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 6.11.0:
  + New versioning scheme.
  + New features:
  - Full support for light/dark GTK theme variants.
  - Side and bottom panels support: rework the API.
  + Bug fixes: TeplTabLabel: correct position for the close button.
  + Misc: Documentation improvements.
- Changes from version 6.10.0:
  + Rename the project from Tepl to libgedit-tepl.
  + libgedit-gfls is used as a new dependency.
  + New APIs: see the API docs.
* Fri Feb 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 6.9.0:
  + libhandy-1 is used as a new dependency (for dark style
    preference handling).
  + Replace _TEPL_EXTERN custom macro by G_MODULE_EXPORT.
  + New APIs: see the API docs.
- Add pkgconfig(libhandy-1) BuildRequires: new dependency.
- Drop pkgconfig(gtksourceview-4) BuildRequires: no longer needed
  since version 6.6.
* Sun Aug 13 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 6.8.0:
  + Update for Amtk -> libgedit-amtk rename.
  + New/changed/removed APIs: see the API docs.
  + A bug fix.
- Add pkgconfig(libgedit-amtk-5), drop pkgconfig(amtk-5)
  BuildRequires following upstreams changes.
- Change lib_ver to %%{api_ver}-4, following upstreams ABI version
  bump.
* Fri Jul 21 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add pkgconfig(libgedit-gtksourceview-300) BuildRequires: new
  dependency since version 6.6.
- Change lib_ver to %%{api_ver}-3, following upstreams ABI version
  bump.
* Fri Jul 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 6.6.0:
  + Nothing transcendental.
* Thu Jan  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 6.4.0:
  + Build: simplify handling of library soversion.
  + Add some new API (see the reference documentation).
  + Some API breaks (see the reference documentation).
  + Experiments to simplify GtkStack custom switcher
    implementations. Moved the result to the attic/ directory.
  + TeplView: add code from gedit: override delete_from_cursor
    vfunc. In gedit it's for the Ctrl+D keybinding to delete the
    current line.
- Bump libver to 2 following upstream changes.
* Fri Nov  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 6.2.0:
  + Remove deprecated API.
  + Add some new API (see the reference documentation).
  + Small improvements.
- Bump lib_ver define to 1 following upstream changes.
- Use ldconfig_scriptlets macro for post(un) handling.
* Tue Sep  6 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 6.1.2:
  + API stability is no longer guaranteed.
  + New features/API: see the index of new symbols in the reference
    documentation (generated with gtk-doc).
  + Documentation improvements.
- Changes from version 6.1.1:
  + New features/API: see the index of new symbols in the reference
    documentation (generated with gtk-doc).
  + Documentation improvements.
- Add pkgconfig(gsettings-desktop-schemas) build requirement. This
  is a new private dependency.
* Wed Jun  1 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 6.0.2:
  + Build system: check if compiler supports --version-script
    linker option.
* Fri May  6 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 6.0.1:
  + No changes.
  - Note that a 6.00.0 version was released in 2021. The double
    00 was a mistake.
* Wed Mar 24 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 6.00.0:
  + API changes: The TeplInfoBar class has been reworked.
  + New API:
  - tepl_pango_font_description_to_css()
  - TeplLanguageChooser
  - TeplLanguageChooserWidget
  - TeplLanguageChooserDialog
  - TeplProgressInfoBar
  - Utility functions: add a few functions.
  + Updated translations.
* Fri Feb 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 5.1.1:
  + Add TeplSpaceDrawerPrefs, a preferences widget for
    GtkSourceSpaceDrawer.
  + Updated translations.
* Fri Nov 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 5.0.1:
  + Updated translations.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 5.0.0:
  + Updated translations.
* Sat Sep  5 2020 dimstar@opensuse.org
- Update to version 4.99.4:
  + Add a few extra functions for GtkFileChooser.
- Changes from version 4.99.3:
  + Start to leverage the ICU library.
- Changes from version 4.99.2:
  + License:
  - Update the license from LGPLv2.1+ to LGPLv3+.
  - Start to use the REUSE way of applying licenses and
    copyrights information, with SPDX tags.
  + API changes: The beginning of a complete overhaul of the file
    loading and saving.
  + New API:
  - 'Go to line' horizontal bar feature.
  - Utility functions: add a function.
  + Under the hood changes:
  - Have _TEPL_EXTERN macro for exporting public symbols.
  - Have a smaller TeplApplicationWindow class, factor out
    several tepl-window-actions-*.{c,h} files.
  + Misc:
  - Improvements to the build system.
  - Metadata: improve the implementation and write unit tests.
  - Init i18n.
  - Tools: add shared-mime-info-list-text-plain-globs.
- Changes from version 4.99.1:
  + Build system: port to Meson, remove Autotools.
  + API changes: A complete overhaul of the metadata API and
    implementation. The libxml2 is no longer required, and GVfs
    metadata is no longer used.
  + Misc:
  - Write a new roadmap in docs/.
  + Updated translations.
- Port to meson buildsystem:
  + Add meson BuildReqequires.
  + Replace configure/make/make_install macros with
    meson/meson_build/meson_install.
- Add pkgconfig(icu-uc) and pkgconfig(icu-i18n) BuildRequires: new
  dependencies.
- Replace pkgconfig(glib-2.0) BuildRequires with
  pkgconfig(gio-2.0): adjust to meson checks.
- Drop pkgconfig(libxml-2.0) BuildRequires: no longer needed.
- Update License tag to LGPL-3.0-or-later: follow upstream change.
* Thu Mar  5 2020 bjorn.lie@gmail.com
- Update to version 4.4.0:
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 4.3.1:
  + Utils functions: make some functions public, add more public
    functions, and write more unit tests.
  + Documentation: introduction: more information about the chosen
    development model.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Nov 21 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.2.1:
  + Fix a few compilation warnings.
  + Better use of errno (save its value ASAP, then reset it to 0).
  + Build from Git:
  - Allow building with gettext ≥ 0.20.
  - Adapt for AX_CODE_COVERAGE API break in autoconf-archive
    version 2019.01.06. (This didn't affect the build from the
    previous tarball, since the Autotools are "bundled" with the
    tarball).
  + Updated translations.
* Mon Jul 23 2018 bjorn.lie@gmail.com
- Update to version 4.2.0:
  + Nothing new, version bump only.
* Wed Jun  6 2018 luc14n0@linuxmail.org
- Drop unnecessary libamtk and amtk typelib Requires for the devel
  package: amtk is a build-time-only dependency.
* Mon Apr 16 2018 luc14n0@linuxmail.org
- Update to version 4.1.1:
  + No visible changes for the user.
- Remove Amtk shared library and GI bindings subpackages: now they
  have their own place under Amtk package.
- Add pkgconfig(amtk-5) BuildRequires now that Amtk has been split.
* Sun Apr  8 2018 bjorn.lie@gmail.com
- Update to version 4.0.0:
  + Project moved to GNOME GitLab.
  + Various small improvements.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Dec  9 2017 luc14n0@linuxmail.org
- Update to version 3.99.1:
  + General: Use GtkSourceView 4.
  + Amtk:
  - Improve amtk_utils_bind_g_action_to_gtk_action() to
    support _detailed_ GAction names.
  - Add amtk_utils_create_gtk_action().
  + Framework:
  - Add:
    . More GAction's and corresponding AmtkActionInfo's:
    win.tepl-undo, win.tepl-redo, win.tepl-indent,
    win.tepl-unindent, win.tepl-open, win.tepl-save,
    win.tepl-save-as and app.tepl-new-window.
    . TeplApplicationWindow:handle-title boolean property to
    handle the window title.
    . More vfuncs to TeplAbstractFactory: create_file and
    create_main_window.
    . TeplAbstractFactoryVala class to work-around Vala bugs.
    . Functions related to main windows:
    tepl_application_get_active_main_window(),
    tepl_application_window_is_main_window(),
    tepl_application_window_get_window_group().
  - TeplApplication: add options to handle the
    GApplication::activate and GApplication::open signals.
  - Start to write high-level functions for loading and saving
    files.
  + File loading and saving toolkit:
  - TeplFileLoader:
    . Internal code refactorings to have more re-usable code
    independent of GtkTextView.
    . Add fallback mode to determine encoding if uchardet fails.
    . Write more unit tests.
  - TeplEncoding:
    . Make tepl_encoding_get_default_candidates() more robust in
    case of mis-translation.
    . Improve API documentation.
  - Write GtkSourceView to Tepl file loading and saving porting
    guide.
  + Translation updates.
- Adopt the use of %%make_build macro instead of raw make command,
  following best practices.
- Replace pattern values by macros to ease updating the package.
- Rename typelib-!_0-{Amtk,Tepl}-3_0 to typelib-1_0-{Amtk,Tepl}-4,
  following the tyeplib naming convention (old name was wrong, but
  as the versoin changed, we don't need to worry to obsolete the
  old name, in line with the shared library packaging policy).
- Add gtk-doc BuildRequires and pass enable-gtk-doc to configure
  once the development documentation is desired.
* Sun Sep 10 2017 jengelh@inai.de
- Update package descriptions.
* Sat Sep  9 2017 dimstar@opensuse.org
- Update to version 3.0.0:
  + Updated translations.
* Fri Sep  1 2017 dimstar@opensuse.org
- Update to version 2.99.4:
  + Amtk:
  - Add factory functions to create GtkMenuToolButton's and
    GtkCheckMenuItem's.
  - Improve amtk_application_window_connect_menu_to_statusbar()
    API.
  - Add amtk_utils_bind_g_action_to_gtk_action(), to be able to
    port an application gradually to GAction while still using
    GtkUIManager.
  + Framework:
  - TeplTabLabel: add an overridable tooltip API, by default the
    tooltip shows the file location.
- Changes from version 2.99.3:
  + Amtk:
  - Add amtk_init() and amtk_finalize().
  - Remove AmtkFactoryMenu class, move its functions to its
    parent class AmtkFactory.
  - AmtkFactory: add functions to create GtkToolItem's.
  - Add amtk_application_window_create_open_recent_menu().
  - Improvements to the documentation.
  - Other small code improvements.
  + Framework:
  - TeplTabGroup interface:
    . Add :active-tab, :active-view and :active-buffer properties.
    . Add tepl_tab_group_set_active_tab().
    . Add tepl_tab_group_append_tab().
  - Finish to implement the GActions for the Edit menu: cut,
    copy, paste, delete and select all. (Update the
    GAction:enabled properties).
  - Add "win.tepl-new-file" GAction.
  - Add the TeplAbstractFactory class to create TeplTab's and tab
    labels.
  - TeplBuffer: rename title -> full-title and add short-title.
  - Add the TeplTab::close-request signal.
  - Add the TeplTabLabel class (which shows the buffer
    short-title, plus a close button; the tooltip is not yet
    handled).
  + Misc:
  - Add tepl_init() and tepl_finalize(), do not use DSO
    constructors/destructors.
  - Implement small internal utility: TeplSignalGroup, inspired
    by DzlSignalGroup from libdazzle, but with a much simpler
    implementation.
  - Improvements to the documentation.
  + Updated translations.
* Wed Aug 23 2017 dimstar@opensuse.org
- Initial package, version 2.99.2, based on gtef (which this
  library was renamed from).
